# AuthenticationDocumentStatus

The configuration for an authentication document

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**issuer** | **str** | The authority that issued this authentication document | [optional] 
**audience** | **str** | Audience(s) that this authentication document is intended for | [optional] 
**key** | **str** | A PEM encoded key that is used to create identity assertions. This key is only returned on creation. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


